# __Mp4ToGif__ #

This is a python libary that will makes a .gif animation out of a .mp4 video. It also uses Pillow to reduce the size of the file.

## Installation ##
1. Go into Cmd/Terminal
1. And now for installing of the package you will need pip(preferred installer program). PIP is normaly installed when you install python. so it's a few different commands it might be depending on if it's in path or not. Try the following one or more of them will proberbly work:
* Py -m pip install Mp4ToGif
* Python -m pip install Mp4ToGif
* Python3 -m pip install Mp4ToGif
* pip install Mp4ToGif

**You have now fully installed Mp4ToGif**

## How to use it ##

It's two methods to run it.
1. Go into Cmd/Terminal and type py/python/python3 -m Mp4ToGif and the path to your .mp4 file.
2. Make a .py file and import Mp4ToGif and type Mp4ToGif.gif( PATH TO MP4 FILE ).

Your .Gif file will appear in the current directory as the .mp4's filename.

## VERSION HISTORY ##

* Version 0.0.1 was testing becuse i had never uploaded a pypi package before.
* Version 0.0.2 was alos testing becuse i had never updated a pypi package before.
* Version 0.0.3 was the first version of the real program and i fixed so that you could run it from another .py program.
* Version 0.0.4 I deleted the package Mp4ToGif and i basicly changed the name of the package i also updated the README.md on github and the description.